@@ -5,6 +5,7 @@ import base64
 import hashlib
 import hmac
 import decimal
+import warnings
 
 from . import exceptions
 from requests_oauthlib import OAuth2Session
@@ -19,6 +20,7 @@ class Environments(object):
 
 
 class QuickBooks(object):
+    MINIMUM_MINOR_VERSION = 75
     company_id = 0
     session = None
     auth_client = None
@@ -74,8 +76,19 @@ class QuickBooks(object):
         if 'company_id' in kwargs:
             instance.company_id = kwargs['company_id']
 
-        if 'minorversion' in kwargs:
-            instance.minorversion = kwargs['minorversion']
+        # Handle minorversion with default
+        instance.minorversion = kwargs.get('minorversion', instance.MINIMUM_MINOR_VERSION)
+        if 'minorversion' not in kwargs:
+            warnings.warn(
+                'No minor version specified. Defaulting to minimum supported version (75). '
+                'Please specify minorversion explicitly when initializing QuickBooks. '
+                'See: https://blogs.intuit.com/2025/01/21/changes-to-our-accounting-api-that-may-impact-your-application/',
+                DeprecationWarning)
+        elif instance.minorversion < instance.MINIMUM_MINOR_VERSION:
+            warnings.warn(
+                f'Minor Version {instance.minorversion} is no longer supported. Minimum supported version is {instance.MINIMUM_MINOR_VERSION}. '
+                'See: https://blogs.intuit.com/2025/01/21/changes-to-our-accounting-api-that-may-impact-your-application/',
+                DeprecationWarning)
 
         instance.invoice_link = kwargs.get('invoice_link', False)
 
@@ -144,13 +157,12 @@ class QuickBooks(object):
         return result
 
     def make_request(self, request_type, url, request_body=None, content_type='application/json',
-                     params=None, file_path=None, request_id=None):
+                     params=None, file_path=None, file_bytes=None, request_id=None):
 
         if not params:
             params = {}
 
-        if self.minorversion:
-            params['minorversion'] = self.minorversion
+        params['minorversion'] = self.minorversion
         
         if request_id:
             params['requestid'] = request_id
@@ -164,7 +176,7 @@ class QuickBooks(object):
             'User-Agent': 'python-quickbooks V3 library'
         }
 
-        if file_path:
+        if file_path or file_bytes:
             url = url.replace('attachable', 'upload')
             boundary = '-------------PythonMultipartPost'
             headers.update({
@@ -175,8 +187,11 @@ class QuickBooks(object):
                 'Connection': 'close'
             })
 
-            with open(file_path, 'rb') as attachment:
-                binary_data = str(base64.b64encode(attachment.read()).decode('ascii'))
+            if file_path:
+                with open(file_path, 'rb') as attachment:
+                    binary_data = str(base64.b64encode(attachment.read()).decode('ascii'))
+            else:
+                binary_data = str(base64.b64encode(file_bytes).decode('ascii'))
 
             content_type = json.loads(request_body)['ContentType']
 
@@ -225,10 +240,16 @@ class QuickBooks(object):
             return result
 
     def get(self, *args, **kwargs):
-        return self.make_request("GET", *args, **kwargs)
+        if 'params' not in kwargs:
+            kwargs['params'] = {}
+
+        return self.make_request('GET', *args, **kwargs)
 
     def post(self, *args, **kwargs):
-        return self.make_request("POST", *args, **kwargs)
+        if 'params' not in kwargs:
+            kwargs['params'] = {}
+
+        return self.make_request('POST', *args, **kwargs)
 
     def process_request(self, request_type, url, headers="", params="", data=""):
         if self.session is None:
@@ -240,10 +261,11 @@ class QuickBooks(object):
             request_type, url, headers=headers, params=params, data=data)
 
     def get_single_object(self, qbbo, pk, params=None):
-        url = "{0}/company/{1}/{2}/{3}/".format(self.api_url, self.company_id, qbbo.lower(), pk)
-        result = self.get(url, {}, params=params)
+        url = "{0}/company/{1}/{2}/{3}".format(self.api_url, self.company_id, qbbo.lower(), pk)
+        if params is None:
+            params = {}
 
-        return result
+        return self.get(url, {}, params=params)
 
     @staticmethod
     def handle_exceptions(results):
@@ -279,11 +301,11 @@ class QuickBooks(object):
             else:
                 raise exceptions.QuickbooksException(message, code, detail)
 
-    def create_object(self, qbbo, request_body, _file_path=None, request_id=None, params=None):
+    def create_object(self, qbbo, request_body, _file_path=None, _file_bytes=None, request_id=None, params=None):
         self.isvalid_object_name(qbbo)
 
         url = "{0}/company/{1}/{2}".format(self.api_url, self.company_id, qbbo.lower())
-        results = self.post(url, request_body, file_path=_file_path, request_id=request_id, params=params)
+        results = self.post(url, request_body, file_path=_file_path, file_bytes=_file_bytes, request_id=request_id, params=params)
 
         return results
 
@@ -299,9 +321,12 @@ class QuickBooks(object):
 
         return True
 
-    def update_object(self, qbbo, request_body, _file_path=None, request_id=None, params=None):
+    def update_object(self, qbbo, request_body, _file_path=None, _file_bytes=None, request_id=None, params=None):
         url = "{0}/company/{1}/{2}".format(self.api_url, self.company_id,  qbbo.lower())
-        result = self.post(url, request_body, file_path=_file_path, request_id=request_id, params=params)
+        if params is None:
+            params = {}
+
+        result = self.post(url, request_body, file_path=_file_path, file_bytes=_file_bytes, request_id=request_id, params=params)
 
         return result
 
