@@ -7,10 +7,10 @@ from .exceptions import QuickbooksException
 from .utils import build_choose_clause, build_where_clause
 
 class DecimalEncoder(json.JSONEncoder):
-    def default(self, obj):
-        if isinstance(obj, decimal.Decimal):
-            return str(obj)
-        return super(DecimalEncoder, self).default(obj)
+    def default(self, o):
+        if isinstance(o, decimal.Decimal):
+            return str(o)
+        return super(DecimalEncoder, self).default(o)
 
 class ToJsonMixin(object):
     def to_json(self):
@@ -21,7 +21,7 @@ class ToJsonMixin(object):
         filter out properties that have names starting with _
         or properties that have a value of None
         """
-        return lambda obj: dict((k, v) for k, v in obj.__dict__.items()
+        return lambda obj: str(obj) if isinstance(obj, decimal.Decimal) else dict((k, v) for k, v in obj.__dict__.items()
                                 if not k.startswith('_') and getattr(obj, k) is not None)
 
 
@@ -255,14 +255,26 @@ class ListMixin(object):
 
     @classmethod
     def all(cls, order_by="", start_position="", max_results=100, qb=None):
-        """
-        :param start_position:
-        :param max_results: The max number of entities that can be returned in a response is 1000.
-        :param qb:
-        :return: Returns list
-        """
-        return cls.where("", order_by=order_by, start_position=start_position,
-                         max_results=max_results, qb=qb)
+        """Returns list of objects containing all objects in the QuickBooks database"""
+        if qb is None:
+            qb = QuickBooks()
+
+        # For Item objects, we need to explicitly request the SKU field
+        if cls.qbo_object_name == "Item":
+            select = "SELECT *, Sku FROM {0}".format(cls.qbo_object_name)
+        else:
+            select = "SELECT * FROM {0}".format(cls.qbo_object_name)
+
+        if order_by:
+            select += " ORDER BY {0}".format(order_by)
+
+        if start_position:
+            select += " STARTPOSITION {0}".format(start_position)
+
+        if max_results:
+            select += " MAXRESULTS {0}".format(max_results)
+
+        return cls.query(select, qb=qb)
 
     @classmethod
     def filter(cls, order_by="", start_position="", max_results="", qb=None, **kwargs):
